@@ -1,7 +1,7 @@
 package Module::Path::More;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.29'; # VERSION
+our $DATE = '2016-01-09'; # DATE
+our $VERSION = '0.30'; # VERSION
 
 use 5.010001;
 use strict;
@@ -11,7 +11,7 @@ require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(module_path pod_path);
 
-my $SEPARATOR;
+our $SEPARATOR;
 
 our %SPEC;
 
@@ -202,7 +202,7 @@ Module::Path::More - Get path to locally installed Perl module
 
 =head1 VERSION
 
-This document describes version 0.29 of Module::Path::More (from Perl distribution Module-Path-More), released on 2015-09-03.
+This document describes version 0.30 of Module::Path::More (from Perl distribution Module-Path-More), released on 2016-01-09.
 
 =head1 SYNOPSIS
 
@@ -270,6 +270,8 @@ interface and more options (finding all matches instead of the first, the option
 of not absolutizing paths, finding C<.pmc> & C<.pod> files, finding module
 prefixes).
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -315,6 +317,8 @@ This is a shortcut for:
 
  module_path(%args, find_pm=>0, find_pmc=>0, find_pod=>1, find_prefix=>0)
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -374,7 +378,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Module-Pat
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Module-Path-More>.
+Source repository is at L<https://github.com/perlancar/perl-Alt-Module-Path-SHARYANTO>.
 
 =head1 BUGS
 
@@ -390,7 +394,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
